| calc_neutral_loss | R Documentation |
calc_neutral_loss() is fully replaced by msn_calc_nl.
Calculate neutral loss spectra for all ions with available MSn spectra in data. To calculate neutral losses, MSn spectra are required.
See read_mgf. This step is required for subsequent filtering based on
neutral losses (filter_neutral_loss). Resulting neutral loss spectra are stored in tibbles in a new list column named Neutral_Loss.
calc_neutral_loss(data, m_z_col)
data |
A tidy tibble created by |
m_z_col |
Which column holds the precursor m/z? Uses |
A tibble with added neutral loss spectra. A new list column is created named Neutral_Loss.
toy_mgf %>%
calc_neutral_loss(m_z_col = PEPMASS)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.