| filter_blank | R Documentation |
Filters Features based on their occurrence in blank samples.
For example, if min_frac = 3 the maximum intensity in samples must be at least 3 times as high as in blanks
for a Feature not to be filtered out.
filter_blank(
data,
blank_samples,
min_frac = 3,
blank_as_group = FALSE,
group_column = NULL
)
data |
A tidy tibble created by |
blank_samples |
Defines the blanks. If |
min_frac |
A numeric defining how many times higher the maximum intensity in samples must be in relation to blanks. |
blank_as_group |
A logical indicating if |
group_column |
Only relevant if |
A filtered tibble.
# Example 1: Define blanks by sample name
toy_metaboscape %>%
filter_blank(blank_samples = c("Blank1", "Blank2"), blank_as_group = FALSE, min_frac = 3)
# Example 2: Define blanks by group name
# toy_metaboscape %>%
# join_metadata(toy_metaboscape_metadata) %>%
# filter_blank(blank_samples = "blank",
# blank_as_group = TRUE,
# min_frac = 3,
# group_column = Group)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.