| impute_bpca | R Documentation |
One of several PCA-based imputation methods. Basically a wrapper around pcaMethods::pca(method = "bpca").
For a detailed discussion, see the vignette("pcaMethods") and vignette("missingValues", "pcaMethods") as well as the References section.
Important Note
impute_bpca() depends on the pcaMethods package from Bioconductor. If metamorphr was installed via install.packages(), dependencies from Bioconductor were not
automatically installed. When impute_bpca() is called without the pcaMethods package installed, you should be asked if you want to install pak and pcaMethods.
If you want to use impute_bpca() you have to install those. In case you run into trouble with the automatic installation, please install pcaMethods manually. See
pcaMethods – a Bioconductor package providing PCA methods for incomplete data.
impute_bpca(data, n_pcs = 2, center = TRUE, scale = "none", direction = 2)
data |
A tidy tibble created by |
n_pcs |
The number of PCs to calculate. |
center |
Should |
scale |
Should |
direction |
Either |
A tibble with imputed missing values.
H. R. Wolfram Stacklies, 2017, DOI 10.18129/B9.BIOC.PCAMETHODS.
W. Stacklies, H. Redestig, M. Scholz, D. Walther, J. Selbig, Bioinformatics 2007, 23, 1164–1167, DOI 10.1093/bioinformatics/btm069.
toy_metaboscape %>%
impute_bpca()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.