| impute_lls | R Documentation |
Basically a wrapper around pcaMethods::llsImpute.
For a detailed discussion, see the vignette("pcaMethods") and vignette("missingValues", "pcaMethods") as well as the References section.
Important Note
impute_lls() depends on the pcaMethods package from Bioconductor. If metamorphr was installed via install.packages(), dependencies from Bioconductor were not
automatically installed. When impute_svd() is called without the pcaMethods package installed, you should be asked if you want to install pak and pcaMethods.
If you want to use impute_lls() you have to install those. In case you run into trouble with the automatic installation, please install pcaMethods manually. See
pcaMethods – a Bioconductor package providing PCA methods for incomplete data for instructions on manual installation.
impute_lls(
data,
correlation = "pearson",
complete_genes = FALSE,
center = FALSE,
cluster_size = 10
)
data |
A tidy tibble created by |
correlation |
The method used to calculate correlations between features. One of |
complete_genes |
If |
center |
Should |
cluster_size |
The number of similar features used for regression. |
A tibble with imputed missing values.
H. R. Wolfram Stacklies, 2017, DOI 10.18129/B9.BIOC.PCAMETHODS.
W. Stacklies, H. Redestig, M. Scholz, D. Walther, J. Selbig, Bioinformatics 2007, 23, 1164–1167, DOI 10.1093/bioinformatics/btm069.
# The cluster size must be reduced because
# the data set is too small for the default (10)
toy_metaboscape %>%
impute_lls(complete_genes = TRUE, cluster_size = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.