impute_median: Impute missing values by replacing them with the Feature...

View source: R/imputes.R

impute_medianR Documentation

Impute missing values by replacing them with the Feature median

Description

Replace missing intensity values (NA) with the Feature median of non-NA values. For example, if a Feature has the measured intensities ⁠NA, 1, NA, 3, 2⁠ in samples 1-5, the intensities after impute_median() would be ⁠2, 1, 2, 3, 2⁠.

Usage

impute_median(data)

Arguments

data

A tidy tibble created by read_featuretable.

Value

A tibble with imputed missing values.

Examples

toy_metaboscape %>%
  impute_median()

metamorphr documentation built on June 10, 2026, 5:07 p.m.