msn_calc_nl: Calculate neutral losses from precursor ion mass and fragment...

View source: R/msn.R

msn_calc_nlR Documentation

Calculate neutral losses from precursor ion mass and fragment ion masses

Description

Calculate neutral loss spectra for all ions with available MSn spectra in data. To calculate neutral losses, MSn spectra are required. See read_mgf. This step is required for subsequent filtering based on neutral losses (filter_neutral_loss). Resulting neutral loss spectra are stored in tibbles in a new list column named Neutral_Loss.

Usage

msn_calc_nl(data, m_z_col)

Arguments

data

A tidy tibble created by read_featuretable.

m_z_col

Which column holds the precursor m/z? Uses args_data_masking.

Value

A tibble with added neutral loss spectra. A new list column is created named Neutral_Loss.

Examples

toy_mgf %>%
  msn_calc_nl(m_z_col = PEPMASS)

metamorphr documentation built on June 10, 2026, 5:07 p.m.