msn_scale: Scale intensities in MSn spectra to the highest value within...

View source: R/msn.R

msn_scaleR Documentation

Scale intensities in MSn spectra to the highest value within each spectrum

Description

Scale the intensity of each peak in an MSn spectrum to that of the highest peak. MSn spectra are required to use this function. See read_mgf.

Important Note

Please note that existing MSn spectra in data will be overwritten.

Usage

msn_scale(data, scale_to = 100)

Arguments

data

A tidy tibble created by read_featuretable.

scale_to

A numeric that specifies to which number the highest signal in each spectrum will be scaled.

Value

A tibble with scaled MSn spectra.

Examples

toy_mgf %>%
  msn_scale()

metamorphr documentation built on June 10, 2026, 5:07 p.m.