| normalize_factor | R Documentation |
Normalization is done by dividing the intensity by a sample-specific factor (e.g., weight, protein or DNA content).
This function requires a sample-specific factor, usually supplied via the Factor column from the sample metadata.
See the Examples section for details.
normalize_factor(data, factor_column = .data$Factor)
data |
A tidy tibble created by |
factor_column |
Which column contains the sample-specific factor? Usually |
A tibble with intensities normalized across samples.
toy_metaboscape %>%
join_metadata(toy_metaboscape_metadata) %>%
normalize_factor()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.