Learn R Programming

metamorphr (version 0.2.0)

normalize_median: Normalize intensities across samples by dividing by the sample median

Description

Normalize across samples by dividing feature intensities by the sample median, making the median 1 in all samples. See References for more information.

Usage

normalize_median(data)

Value

A tibble with intensities normalized across samples.

Arguments

data

A tidy tibble created by read_featuretable.

References

T. Ramirez, A. Strigun, A. Verlohner, H.-A. Huener, E. Peter, M. Herold, N. Bordag, W. Mellert, T. Walk, M. Spitzer, X. Jiang, S. Sperber, T. Hofmann, T. Hartung, H. Kamp, B. Van Ravenzwaay, Arch Toxicol 2018, 92, 893–906, DOI 10.1007/s00204-017-2079-6.

Examples

Run this code
toy_metaboscape %>%
  normalize_median()

Run the code above in your browser using DataLab