| normalize_pqn | R Documentation |
This method was originally developed for H-NMR spectra of complex biofluids but has been adapted for other 'omics data. It aims to eliminate dilution effects by calculating the most probable dilution factor for each sample, relative to one or more reference samples. See references for more details.
normalize_pqn(
data,
fn = "median",
normalize_sum = TRUE,
reference_samples = NULL,
ref_as_group = FALSE,
group_column = NULL
)
data |
A tidy tibble created by |
fn |
Which function should be used to calculate the reference spectrum from the reference samples? Can be either "mean" or "median". |
normalize_sum |
A logical indicating whether a sum normalization (aka total area normalization) should be performed prior to PQN. It is recommended to do so and other packages (e.g., KODAMA) also perform a sum normalization prior to PQN. |
reference_samples |
Either |
ref_as_group |
A logical indicating if |
group_column |
Only relevant if |
A tibble with intensities normalized across samples.
F. Dieterle, A. Ross, G. Schlotterbeck, H. Senn, Anal. Chem. 2006, 78, 4281–4290, DOI 10.1021/ac051632c.
# specify the reference samples with their sample names
toy_metaboscape %>%
impute_lod() %>%
normalize_pqn(reference_samples = c("QC1", "QC2", "QC3"))
# specify the reference samples with their group names
toy_metaboscape %>%
join_metadata(toy_metaboscape_metadata) %>%
impute_lod() %>%
normalize_pqn(reference_samples = c("QC"), ref_as_group = TRUE, group_column = Group)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.