| normalize_quantile_group | R Documentation |
This function performs a Quantile Normalization on each sub-group in the data set. It therefore requires grouping information. See
Examples for more information. This approach might perform better than the standard approach, normalize_quantile_all,
if sub-groups are very different (e.g., when comparing cancer vs. normal tissue).
Other sub-flavors are also available:
normalize_quantile_all
normalize_quantile_batch
normalize_quantile_smooth
See References for more information. Note that it is equivalent to the 'Class-specific' normalization in Zhao et al. but has been renamed for internal consistency.
normalize_quantile_group(data, group_column = .data$Group)
data |
A tidy tibble created by |
group_column |
Which column should be used for grouping? Usually |
A tibble with intensities normalized across samples.
Y. Zhao, L. Wong, W. W. B. Goh, Sci Rep 2020, 10, 15534, DOI 10.1038/s41598-020-72664-6.
toy_metaboscape %>%
# Metadata, including grouping information, must be added before using normalize_quantile_group()
join_metadata(toy_metaboscape_metadata) %>%
normalize_quantile_group(group_column = Group)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.