| normalize_quantile_smooth | R Documentation |
This function performs a smooth Quantile Normalization on each sub-group in the data set (qsmooth). It therefore requires grouping information. See
Examples for more information. This approach might perform better than the standard approach, normalize_quantile_all,
if sub-groups are very different (e.g., when comparing cancer vs. normal tissue). The result lies somewhere between normalize_quantile_group
and normalize_quantile_all. Basically a re-implementation of Hicks et al. (2018).
normalize_quantile_smooth(
data,
group_column = .data$Group,
rolling_window = 0.05
)
data |
A tidy tibble created by |
group_column |
Which column should be used for grouping? Usually |
rolling_window |
|
A tibble with intensities normalized across samples.
S. C. Hicks, K. Okrah, J. N. Paulson, J. Quackenbush, R. A. Irizarry, H. C. Bravo, Biostatistics 2018, 19, 185–198, DOI 10.1093/biostatistics/kxx028.
Y. Zhao, L. Wong, W. W. B. Goh, Sci Rep 2020, 10, 15534, DOI 10.1038/s41598-020-72664-6.
toy_metaboscape %>%
# Metadata, including grouping information, must be added before using normalize_quantile_group()
join_metadata(toy_metaboscape_metadata) %>%
normalize_quantile_smooth(group_column = Group)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.