| normalize_sum | R Documentation |
Normalize across samples by dividing feature intensities by the sum of all intensities in a sample, making the sum 1 in all samples.
Important Note
Intensities of individual features will be very small after this normalization approach. It is therefore advised to multiply all intensities with a fixed number (e.g., 1000) after normalization. See this discussion on OMICSForum.ca and the examples below for further information.
normalize_sum(data)
data |
A tidy tibble created by |
A tibble with intensities normalized across samples.
# Example 1: Normalization only
toy_metaboscape %>%
normalize_sum()
# Example 2: Multiply with 1000 after normalization
toy_metaboscape %>%
normalize_sum() %>%
dplyr::mutate(Intensity = .data$Intensity * 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.