scale_center: Center intensities of features around zero

View source: R/scale.R

scale_centerR Documentation

Center intensities of features around zero

Description

Centers the intensities of all features around zero using

\widetilde{x}_{ij}=x_{ij}-\overline{x}_{i}

where \widetilde{x}_{ij} is the intensity of sample j, feature i after scaling, x_{ij} is the intensity of sample j, feature i before scaling and \overline{x}_{i} is the mean of intensities of feature i across all samples. In other words, it subtracts the mean intensity of a feature across samples from the intensities of that feature in each sample. For more information, see the reference section.

Usage

scale_center(data)

Arguments

data

A tidy tibble created by read_featuretable.

Value

A tibble with intensities scaled around zero.

References

  • R. A. Van Den Berg, H. C. Hoefsloot, J. A. Westerhuis, A. K. Smilde, M. J. Van Der Werf, BMC Genomics 2006, 7, 142, DOI 10.1186/1471-2164-7-142.

Examples

toy_metaboscape %>%
  scale_center()

metamorphr documentation built on June 10, 2026, 5:07 p.m.