scale_level: Scale intensities of features using level scaling

View source: R/scale.R

scale_levelR Documentation

Scale intensities of features using level scaling

Description

Scales the intensities of all features using

\widetilde{x}_{ij}=\frac{x_{ij}-\overline{x}_{i}}{\overline{x}_{i}}

where \widetilde{x}_{ij} is the intensity of sample j, feature i after scaling, x_{ij} is the intensity of sample j, feature i before scaling and \overline{x}_{i} is the mean of intensities of feature i across all samples

In other words, it performs centering (scale_center) and divides by the feature mean, thereby focusing on the relative intensity.

Usage

scale_level(data)

Arguments

data

A tidy tibble created by read_featuretable.

Value

A tibble with level scaled intensities.

References

  • R. A. Van Den Berg, H. C. Hoefsloot, J. A. Westerhuis, A. K. Smilde, M. J. Van Der Werf, BMC Genomics 2006, 7, 142, DOI 10.1186/1471-2164-7-142.

Examples

toy_metaboscape %>%
  impute_lod() %>%
  scale_level()

metamorphr documentation built on June 10, 2026, 5:07 p.m.