| scale_pareto | R Documentation |
Scales the intensities of all features using
\widetilde{x}_{ij}=\frac{x_{ij}-\overline{x}_{i}}{\sqrt{s_i}}
where \widetilde{x}_{ij} is the intensity of sample j, feature i after scaling,
x_{ij} is the intensity of sample j, feature i before scaling, \overline{x}_{i} is the mean of intensities of feature i across all samples
and {\sqrt{s_i}} is the square root of the standard deviation of intensities of feature i across all samples.
In other words, it subtracts the mean intensity of a feature across samples from the intensities of that feature in each sample and divides by the square root of the standard deviation of that feature.
For more information, see the reference section.
scale_pareto(data)
data |
A tidy tibble created by |
A tibble with autoscaled intensities.
R. A. Van Den Berg, H. C. Hoefsloot, J. A. Westerhuis, A. K. Smilde, M. J. Van Der Werf, BMC Genomics 2006, 7, 142, DOI 10.1186/1471-2164-7-142.
toy_metaboscape %>%
scale_pareto()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.