scale_vast: Scale intensities of features using vast scaling

View source: R/scale.R

scale_vastR Documentation

Scale intensities of features using vast scaling

Description

Scales the intensities of all features using

\widetilde{x}_{ij}=\frac{x_{ij}-\overline{x}_{i}}{s_i}\cdot \frac{\overline{x}_{i}}{s_i}

where \widetilde{x}_{ij} is the intensity of sample j, feature i after scaling, x_{ij} is the intensity of sample j, feature i before scaling, \overline{x}_{i} is the mean of intensities of feature i across all samples and {s_i} is the standard deviation of intensities of feature i across all samples. Note that \frac{\overline{x}_{i}}{s_i} = \frac{{1}}{CV} where CV is the coefficient of variation across all samples. scale_vast_grouped is a variation of this function that uses a group-specific coefficient of variation. In other words, it performs autoscaling (scale_auto) and divides by the coefficient of variation, thereby reducing the importance of features with a poor reproducibility.

Usage

scale_vast(data)

Arguments

data

A tidy tibble created by read_featuretable.

Value

A tibble with vast scaled intensities.

References

  • R. A. Van Den Berg, H. C. Hoefsloot, J. A. Westerhuis, A. K. Smilde, M. J. Van Der Werf, BMC Genomics 2006, 7, 142, DOI 10.1186/1471-2164-7-142.

  • J. Sun, Y. Xia, Genes & Diseases 2024, 11, 100979, DOI 10.1016/j.gendis.2023.04.018.

Examples

toy_metaboscape %>%
  scale_vast()

metamorphr documentation built on June 10, 2026, 5:07 p.m.