| summary_featuretable | R Documentation |
Information about a feature table. Prints information to the console (number of samples, number of features and if applicable number of groups, replicates and batches) and returns a sample-wise summary as a list.
summary_featuretable(
data,
n_samples_max = 5,
n_features_max = 5,
n_groups_max = 5,
n_batches_max = 5
)
data |
A tidy tibble created by |
n_samples_max |
How many Samples should be printed to the console? |
n_features_max |
How many Features should be printed to the console? |
n_groups_max |
How many groups should be printed to the console? |
n_batches_max |
How many Batches should be printed to the console? |
A sample-wise summary as a list.
toy_metaboscape %>%
join_metadata(toy_metaboscape_metadata) %>%
summary_featuretable()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.