The raw feature table is also included.
This tibble can be reproduced with metamorphr::read_featuretable(system.file("extdata", "toy_metaboscape.csv", package = "metamorphr"), metadata_cols = 2:5).
toy_metaboscapetoy_metaboscape
A data frame with 110 rows and 8 columns:
A unique identifier for each Feature. This column is automatically generated by metamorphr::read_featuretable() when the feature table is imported.
A label given to each Feature for easier identification. The column of the original feature table that is used to generate the Feature column is specified with the label_col argument of metamorphr::read_featuretable().
Sample name. Column names in the original feature table.
Measured intensity (or area).
Retention time. Feature metadata and therefore not really necessary.
Mass over charge. Feature metadata and therefore not really necessary.
Feature name. Feature metadata and therefore not really necessary.
Chemical formula. Feature metadata and therefore not really necessary.
...