# Calculate the Kendrick masses for two measured masses with
# CH2 as the repeating unit.
# See Hughey et al. in the References section above
calc_km(c(351.3269, 365.3425))
# Construct a KMD plot from m/z values.
# RT is mapped to color and the feature-wise maximum intensity to size.
# Note that in the publication by Hughey et al., the nominal Kendrick mass
# is used on the x-axis instead of the exact Kendrick mass.
# See ?calc_nominal_km.
toy_metaboscape %>%
dplyr::group_by(UID, `m/z`, RT) %>%
dplyr::summarise(max_int = max(Intensity, na.rm = TRUE)) %>%
dplyr::ungroup() %>%
dplyr::mutate(KMD = calc_kmd(`m/z`),
KM = calc_km(`m/z`)) %>%
ggplot2::ggplot(ggplot2::aes(x = KM,
y = KMD,
size = max_int,
color = RT)) +
ggplot2::geom_point()
Run the code above in your browser using DataLab