| filter_global_mv | R Documentation |
Filters features based on the number or fraction of samples they are found in. This is usually one of the first steps in metabolomics data analysis and often already performed when the feature table is first created from the raw spectral files..
filter_global_mv(data, min_found = 0.5, fraction = TRUE)
data |
A tidy tibble created by |
min_found |
In how many samples must a Feature be found? If |
fraction |
Either |
A filtered tibble.
# Example 1: A feature must be found in at least 50 % of the samples
toy_metaboscape %>%
filter_global_mv(min_found = 0.5)
# Example 2: A feature must be found in at least 8 samples
toy_metaboscape %>%
filter_global_mv(min_found = 8, fraction = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.