| filter_grouped_mv | R Documentation |
Similar to filter_global_mv it filters features that are found in a specified number of samples.
The key difference is that filter_grouped_mv() takes groups into consideration and therefore needs sample metadata.
For example, if fraction = TRUE and min_found = 0.5, a feature must be found in at least 50 % of the samples of at least 1 group.
It is very similar to the Filter features by occurrences in groups option in Bruker MetaboScape.
filter_grouped_mv(
data,
min_found = 0.5,
group_column = .data$Group,
fraction = TRUE
)
data |
A tidy tibble created by |
min_found |
Defines in how many samples of at least 1 group a Feature must be found not to be filtered out. If |
group_column |
Which column should be used for grouping? Usually |
fraction |
Either |
A filtered tibble.
# A Feature must be found in all samples of at least 1 group.
toy_metaboscape %>%
join_metadata(toy_metaboscape_metadata) %>%
filter_grouped_mv(min_found = 1, group_column = Group)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.