Learn R Programming

metamorphr (version 0.2.0)

impute_lod: Impute missing values by replacing them with the Feature 'Limit of Detection'

Description

Replace missing intensity values (NA) by what is assumed to be the detector limit of detection (LoD). It is estimated by dividing the Feature minimum by the provided denominator, usually 5. See the References section for more information.

Usage

impute_lod(data, div_by = 5)

Value

A tibble with imputed missing values.

Arguments

data

A tidy tibble created by read_featuretable.

div_by

A numeric value that specifies by which number the Feature minimum will be divided

References

LoD on OmicsForum

Examples

Run this code
toy_metaboscape %>%
  impute_lod()

Run the code above in your browser using DataLab