impute_mean: Impute missing values by replacing them with the Feature mean
Description
Replace missing intensity values (NA) with the Feature mean of non-NA values. For example, if a Feature has the measured intensities NA, 1, NA, 3, 2 in samples 1-5,
the intensities after impute_mean() would be 2, 1, 2, 3, 2.