Learn R Programming

metamorphr (version 0.3.0)

impute_median: Impute missing values by replacing them with the Feature median

Description

Replace missing intensity values (NA) with the Feature median of non-NA values. For example, if a Feature has the measured intensities NA, 1, NA, 3, 2 in samples 1-5, the intensities after impute_median() would be 2, 1, 2, 3, 2.

Usage

impute_median(data)

Value

A tibble with imputed missing values.

Arguments

data

A tidy tibble created by read_featuretable.

Examples

Run this code
toy_metaboscape %>%
  impute_median()

Run the code above in your browser using DataLab