Learn R Programming

metamorphr (version 0.3.0)

msn_scale: Scale intensities in MSn spectra to the highest value within each spectrum

Description

Scale the intensity of each peak in an MSn spectrum to that of the highest peak. MSn spectra are required to use this function. See read_mgf.

Important Note

Please note that existing MSn spectra in data will be overwritten.

Usage

msn_scale(data, scale_to = 100)

Value

A tibble with scaled MSn spectra.

Arguments

data

A tidy tibble created by read_featuretable.

scale_to

A numeric that specifies to which number the highest signal in each spectrum will be scaled.

Examples

Run this code
toy_mgf %>%
  msn_scale()

Run the code above in your browser using DataLab