Learn R Programming

metamorphr (version 0.2.0)

normalize_quantile_batch: Normalize intensities across samples using grouped Quantile Normalization with multiple batches

Description

This function performs a Quantile Normalization on each sub-group and batch in the data set. It therefore requires grouping information. See Examples for more information. This approach might perform better than the standard approach, normalize_quantile_all, if sub-groups are very different (e.g., when comparing cancer vs. normal tissue).

Other sub-flavors are also available:

  • normalize_quantile_all

  • normalize_quantile_batch

  • normalize_quantile_smooth

See References for more information. Note that it is equivalent to the 'Discrete' normalization in Zhao et al. but has been renamed for internal consistency.

Usage

normalize_quantile_batch(
  data,
  group_column = .data$Group,
  batch_column = .data$Batch
)

Value

A tibble with intensities normalized across samples.

Arguments

data

A tidy tibble created by read_featuretable.

group_column

Which column should be used for grouping? Usually grouping_column = Group. Uses args_data_masking.

batch_column

Which column contains the batch information? Usually grouping_column = Batch. Uses args_data_masking.

References

Y. Zhao, L. Wong, W. W. B. Goh, Sci Rep 2020, 10, 15534, DOI 10.1038/s41598-020-72664-6.

Examples

Run this code
toy_metaboscape %>%
  # Metadata, including grouping and batch information,
  # must be added before using normalize_quantile_batch()
  join_metadata(toy_metaboscape_metadata) %>%
  normalize_quantile_batch(group_column = Group, batch_column = Batch)

Run the code above in your browser using DataLab