This function performs a Quantile Normalization on each sub-group in the data set. It therefore requires grouping information. See
Examples for more information. This approach might perform better than the standard approach, normalize_quantile_all,
if sub-groups are very different (e.g., when comparing cancer vs. normal tissue).
Other sub-flavors are also available:
See References for more information.
Note that it is equivalent to the 'Class-specific' normalization in Zhao et al. but has been renamed for internal consistency.