Learn R Programming

metamorphr (version 0.3.0)

normalize_sum: Normalize intensities across samples by dividing by the sample sum

Description

Normalize across samples by dividing feature intensities by the sum of all intensities in a sample, making the sum 1 in all samples.

Important Note

Intensities of individual features will be very small after this normalization approach. It is therefore advised to multiply all intensities with a fixed number (e.g., 1000) after normalization. See this discussion on OMICSForum.ca and the examples below for further information.

Usage

normalize_sum(data)

Value

A tibble with intensities normalized across samples.

Arguments

data

A tidy tibble created by read_featuretable.

Examples

Run this code
# Example 1: Normalization only
toy_metaboscape %>%
  normalize_sum()

# Example 2: Multiply with 1000 after normalization
toy_metaboscape %>%
  normalize_sum() %>%
  dplyr::mutate(Intensity = .data$Intensity * 1000)

Run the code above in your browser using DataLab