- data
A tidy tibble created by read_featuretable.
- group_column
Which column should be used for grouping? Usually group_column = Group. Uses args_data_masking.
- name_column
Which column contains the feature names? Can for example be name_column = UID or name_column = Feature. Uses args_data_masking.
- groups_to_compare
Names of the groups which should be compared as a character vector. Those are the group names in the group_column. They are usually provided in the form of a metadata tibble and joined via join_metadata.
- batch_column
Which column contains the batch information? Usually grouping_column = Batch. Only relevant if data contains multiple batches. For example, if data contains 2 batches and each batch contains measurements of separate controls, group_column and batch arguments should be provided. Otherwise controls of both batches will be considered when calculating the p-value and log2 fold change. Uses args_data_masking.
- batch
The names of the batch(es) that should be included when calculating p-value and log2 fold change.
- log2fc_cutoff
A numeric. What cutoff should be used for the log2 fold change? Traditionally, this is set to 1 which corresponds to a doubling or halving of intensity or area compared to a control. This is only important for assignment to groups and colors defined in the colors argument.
- p_value_cutoff
A numeric. What cutoff should be used for the p-value? Traditionally, this is set to 0.05. This is only important for assignment to groups and colors defined in the colors argument. Note that this is not the -log10 transformed value.
- colors
A named list for coloring the dots in the Volcano Plot or NULL in case the points should not be colored. The list must contain colors for the following groups: sig_up, sig_down, not_sig_up, not_sig_down and not_sig.
- adjust_p
Should the p-value be adjusted? Can be either FALSE, (the default) in case no adjustment should be made or any or the name from p.adjust.methods (e.g., adjust_p = "fdr").
- log2_before
A logical. Should the data be log2 transformed prior to calculating the p-values?
- return_tbl
A logical. If FALSE, returns a ggplot2 object, if TRUE returns a tibble which can be used to draw the plot manually to have more control.
- ...
Arguments passed on to t.test. If none are provided (the default), a Welch Two Sample t-test will be performed.