| read_featuretable_mzmine | R Documentation |
Similar to read_featuretable but specifically for full_feature_table' files created with 'mzmine'. For more information, see the 'mzmine' documentation.
read_featuretable_mzmine(
file,
intensity = "height",
field_separator = ",",
label_col = 1,
import_datafile_cols = FALSE,
remove_empty_cols = FALSE,
show_removed_cols = TRUE
)
file |
A path to a file but can also be a connection or literal data. |
intensity |
A character that specifies what should be used as the (semi-)quantitative measure. Either |
field_separator |
The field separator as specified in 'mzmine'. Usually |
label_col |
The index or name (as a character) of the column that will be used to label Features. For example an identifier (e.g., KEGG, CAS, HMDB) or a m/z-RT pair. |
import_datafile_cols |
Should columns that begin with |
remove_empty_cols |
Either |
show_removed_cols |
Only relevant if |
A tidy tibble.
H. Wickham, J. Stat. Soft. 2014, 59, DOI 10.18637/jss.v059.i10.
H. Wickham, M. Averick, J. Bryan, W. Chang, L. McGowan, R. François, G. Grolemund, A. Hayes, L. Henry, J. Hester, M. Kuhn, T. Pedersen, E. Miller, S. Bache, K. Müller, J. Ooms, D. Robinson, D. Seidel, V. Spinu, K. Takahashi, D. Vaughan, C. Wilke, K. Woo, H. Yutani, JOSS 2019, 4, 1686, DOI 10.21105/joss.01686.
“12 Tidy data | R for Data Science,” can be found under https://r4ds.had.co.nz/tidy-data.html, 2023.
# Read a toy dataset in the format produced with mzmine.
featuretable_path <- system.file("extdata", "toy_mzmine.csv", package = "metamorphr")
# Example 1: Use feature height as the metric
featuretable <- read_featuretable_mzmine(
featuretable_path,
intensity = "height"
)
featuretable
# Example 2: Use the 'mz' column as a Feature label
featuretable <- read_featuretable_mzmine(
featuretable_path,
label_col = "mz"
)
featuretable
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.