MGF files allow the storage of MS/MS spectra. This
function reads them into a tidy tibble. Each variable is stored in a column and each ion (observation) is stored in a separate row.
MS/MS spectra are stored in a list column named MSn.
Please note that MGF files are software-specific so the variables
and their names may vary. This function was developed with the GNPS file format exported from mzmine in mind.