Scales the intensities of all features using
$$\widetilde{x}_{ij}=\frac{x_{ij}-\overline{x}_{i}}{s_i}$$
where \(\widetilde{x}_{ij}\) is the intensity of sample \(j\), feature \(i\) after scaling,
\(x_{ij}\) is the intensity of sample \(j\), feature \(i\) before scaling, \(\overline{x}_{i}\) is the mean of intensities of feature \(i\) across all samples
and \({s_i}\) is the standard deviation of intensities of feature \(i\) across all samples.
In other words, it subtracts the mean intensity of a feature across samples from the intensities of that feature in each sample and divides by the standard deviation of that feature.
For more information, see the reference section.