Centers the intensities of all features around zero using
$$\widetilde{x}_{ij}=x_{ij}-\overline{x}_{i}$$
where \(\widetilde{x}_{ij}\) is the intensity of sample \(j\), feature \(i\) after scaling,
\(x_{ij}\) is the intensity of sample \(j\), feature \(i\) before scaling and \(\overline{x}_{i}\) is the mean of intensities of feature \(i\) across all samples.
In other words, it subtracts the mean intensity of a feature across samples from the intensities of that feature in each sample.
For more information, see the reference section.