| scale_level | R Documentation |
Scales the intensities of all features using
\widetilde{x}_{ij}=\frac{x_{ij}-\overline{x}_{i}}{\overline{x}_{i}}
where \widetilde{x}_{ij} is the intensity of sample j, feature i after scaling,
x_{ij} is the intensity of sample j, feature i before scaling and \overline{x}_{i} is the mean of intensities of feature i across all samples
In other words, it performs centering (scale_center) and divides by the feature mean, thereby focusing on the relative intensity.
scale_level(data)
data |
A tidy tibble created by |
A tibble with level scaled intensities.
R. A. Van Den Berg, H. C. Hoefsloot, J. A. Westerhuis, A. K. Smilde, M. J. Van Der Werf, BMC Genomics 2006, 7, 142, DOI 10.1186/1471-2164-7-142.
toy_metaboscape %>%
impute_lod() %>%
scale_level()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.