Learn R Programming

metamorphr (version 0.2.0)

scale_range: Scale intensities of features using range scaling

Description

Scales the intensities of all features using

$$\widetilde{x}_{ij}=\frac{x_{ij}-\overline{x}_{i}}{x_{i,max}-x_{i,min}}$$

where \(\widetilde{x}_{ij}\) is the intensity of sample \(j\), feature \(i\) after scaling, \(x_{ij}\) is the intensity of sample \(j\), feature \(i\) before scaling, \(\overline{x}_{i}\) is the mean of intensities of feature \(i\) across all samples, \(x_{i,max}\) is the maximum intensity of feature \(i\) across all samples and \(x_{i,min}\) is the minimum intensity of feature \(i\) across all samples. In other words, it subtracts the mean intensity of a feature across samples from the intensities of that feature in each sample and divides by the range of that feature. For more information, see the reference section.

Usage

scale_range(data)

Value

A tibble with range scaled intensities.

Arguments

data

A tidy tibble created by read_featuretable.

References

  • R. A. Van Den Berg, H. C. Hoefsloot, J. A. Westerhuis, A. K. Smilde, M. J. Van Der Werf, BMC Genomics 2006, 7, 142, DOI 10.1186/1471-2164-7-142.

Examples

Run this code
toy_metaboscape %>%
  scale_range()

Run the code above in your browser using DataLab