summary_featuretable: General information about a feature table and sample-wise summary
Description
Information about a feature table. Prints information to the console (number of samples, number of features and if applicable number of groups,
replicates and batches) and returns a sample-wise summary as a list.
Usage
summary_featuretable(
data,
n_samples_max = 5,
n_features_max = 5,
n_groups_max = 5,
n_batches_max = 5
)
Value
A sample-wise summary as a list.
Arguments
- data
A tidy tibble created by read_featuretable.
- n_samples_max
How many Samples should be printed to the console?
- n_features_max
How many Features should be printed to the console?
- n_groups_max
How many groups should be printed to the console?
- n_batches_max
How many Batches should be printed to the console?
Examples
Run this codetoy_metaboscape %>%
join_metadata(toy_metaboscape_metadata) %>%
summary_featuretable()
Run the code above in your browser using DataLab