toy_metaboscapeData was generated with metamorphr::create_metadata_skeleton() and can be reproduced with
metamorphr::toy_metaboscape %>% create_metadata_skeleton().'
toy_metaboscape_metadatatoy_metaboscape_metadata
A data frame with 11 rows and 5 columns:
The sample name
To which group does the samples belong? For example a treatment or a background. Note that additional columns with additional grouping information can be freely added if necessary.
The replicate.
The batch in which the samples were prepared or measured.
A sample-specific factor, for example dry weight or protein content.
...